==> letmego-0.9.0.tar.gz: letmego-0.9.0/README.md <==
# Let Me Go

> letmego.

![PyPI](https://img.shields.io/pypi/v/letmego?style=flat&logo=github&link=https%3A%2F%2Fpypi.org%2Fproject%2Fletmego%2F)
![PyPI - License](https://img.shields.io/pypi/l/letmego)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/letmego)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/letmego)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/letmego)

[![Downloads](https://static.pepy.tech/badge/letmego/week)](https://pepy.tech/project/letmego)
[![Downloads](https://static.pepy.tech/badge/letmego/month)](https://pepy.tech/project/letmego)
[![Downloads](https://static.pepy.tech/badge/letmego)](https://pepy.tech/project/letmego)

English | [简体中文](README.zh_CN.md) 

letmego is 

## Installation

- Installing from PyPI:

  ```shel
  sudo pip3 install letmego
  ```

## Usage

```sh
xx
```

## Documentations

- [Documents](https://mikigo.github.io/letmego/)

## Getting help

- [Official Forum](https://bbs.deepin.org/) for generic discussion and help.
- [Developer Center](https://github.com/linuxdeepin/developer-center) for BUG report and suggestions.
- [Wiki](https://wiki.deepin.org/)

## Getting involved

We encourage you to report issues and contribute changes

- [Contribution guide for developers](https://github.com/linuxdeepin/developer-center/wiki/Contribution-Guidelines-for-Developers-en) (English)
- [Translate for your language on Transifex](#) *please update to the actual Transifex link of this project*

## License

letmego is licensed under [Apache](LICENSE)

==> letmego-0.9.6.tar.gz: letmego-0.9.6/README.md <==
# Let Me Go

![PyPI](https://img.shields.io/pypi/v/letmego?style=flat&logo=github&link=https%3A%2F%2Fpypi.org%2Fproject%2Fletmego%2F)
![PyPI - License](https://img.shields.io/pypi/l/letmego)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/letmego)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/letmego)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/letmego)

[![Downloads](https://static.pepy.tech/badge/letmego/week)](https://pepy.tech/project/letmego)
[![Downloads](https://static.pepy.tech/badge/letmego/month)](https://pepy.tech/project/letmego)
[![Downloads](https://static.pepy.tech/badge/letmego)](https://pepy.tech/project/letmego)

English | [简体中文](README.zh_CN.md) 

letmego is a solution to control the execution of Python functions. At present, the main application scenario is in the scenario where the automated test program has to be interrupted, such as the restart scenario. It is necessary to restart the machine during the execution of the steps of the automated use case. After the machine restarts, it can be restarted. Continues the functionality performed by the use case step immediately before the restart.

## Installation

- Installing from PyPI:

  ```shel
  pip3 install letmego
  ```

## Documentations

- [Documents](https://mikigo.github.io/letmego/)

## Getting help

- [Official Forum](https://bbs.deepin.org/) for generic discussion and help.
- [Developer Center](https://github.com/linuxdeepin/developer-center) for BUG report and suggestions.
- [Wiki](https://wiki.deepin.org/)

## Getting involved

We encourage you to report issues and contribute changes

- [Contribution guide for developers](https://github.com/linuxdeepin/developer-center/wiki/Contribution-Guidelines-for-Developers-en) (English)
- [Translate for your language on Transifex](#) *please update to the actual Transifex link of this project*

## License

letmego is licensed under [Apache](LICENSE)
